==> zio-aws-amplifybackend_2.12-5.17.295.5-sources.jar: zio/aws/amplifybackend/model/EmailSettings.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EmailSettings(
    emailMessage: Optional[__string] = Optional.Absent,
    emailSubject: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.EmailSettings = {
    import EmailSettings.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.EmailSettings
      .builder()
      .optionallyWith(emailMessage.map(value => value: java.lang.String))(
        _.emailMessage
      )
      .optionallyWith(emailSubject.map(value => value: java.lang.String))(
        _.emailSubject
      )
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.EmailSettings.ReadOnly =
    zio.aws.amplifybackend.model.EmailSettings.wrap(buildAwsValue())
}
object EmailSettings {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.EmailSettings
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.EmailSettings =
      zio.aws.amplifybackend.model.EmailSettings(
        emailMessage.map(value => value),
        emailSubject.map(value => value)
      )
    def emailMessage: Optional[__string]
    def emailSubject: Optional[__string]
    def getEmailMessage: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("emailMessage", emailMessage)
    def getEmailSubject: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("emailSubject", emailSubject)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.EmailSettings
  ) extends zio.aws.amplifybackend.model.EmailSettings.ReadOnly {
    override val emailMessage: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.emailMessage())
      .map(value => value: __string)
    override val emailSubject: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.emailSubject())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.EmailSettings
  ): zio.aws.amplifybackend.model.EmailSettings.ReadOnly = new Wrapper(impl)
}

==> zio-aws-amplifybackend_2.13-5.17.123.1-sources.jar: zio/aws/amplifybackend/model/EmailSettings.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class EmailSettings(
    emailMessage: Option[__string] = None,
    emailSubject: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.EmailSettings = {
    import EmailSettings.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.EmailSettings
      .builder()
      .optionallyWith(
        emailMessage.map(value => __string.unwrap(value): java.lang.String)
      )(_.emailMessage)
      .optionallyWith(
        emailSubject.map(value => __string.unwrap(value): java.lang.String)
      )(_.emailSubject)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.EmailSettings.ReadOnly =
    zio.aws.amplifybackend.model.EmailSettings.wrap(buildAwsValue())
}
object EmailSettings {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.EmailSettings
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.EmailSettings =
      zio.aws.amplifybackend.model.EmailSettings(
        emailMessage.map(value => value),
        emailSubject.map(value => value)
      )
    def emailMessage: Option[__string]
    def emailSubject: Option[__string]
    def getEmailMessage: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("emailMessage", emailMessage)
    def getEmailSubject: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("emailSubject", emailSubject)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.EmailSettings
  ) extends zio.aws.amplifybackend.model.EmailSettings.ReadOnly {
    override val emailMessage: Option[__string] = scala
      .Option(impl.emailMessage())
      .map(value => zio.aws.amplifybackend.model.primitives.__string(value))
    override val emailSubject: Option[__string] = scala
      .Option(impl.emailSubject())
      .map(value => zio.aws.amplifybackend.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.EmailSettings
  ): zio.aws.amplifybackend.model.EmailSettings.ReadOnly = new Wrapper(impl)
}
